@@ -63,10 +63,10 @@
 
 #include <tqlabel.h>
 
-#include <kmainwindow.h>
-#include <klocale.h>
+#include <tdemainwindow.h>
+#include <tdelocale.h>
 
-#include <kmenubar.h>
+#include <tdemenubar.h>
 #include <tqlayout.h>
 #include <tqkeysequence.h>
 #include <knuminput.h>
@@ -77,12 +77,12 @@
 #include <kiconloader.h>
 #include "kexportdialog.h"
 #include "kjtagdialog.h"
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <tqlayout.h>
 #include <ksimpleconfig.h>
 #include <khelpmenu.h>
-#include <kaboutdata.h>
+#include <tdeaboutdata.h>
 
 const char version[] = "0.6" ;
 
@@ -99,7 +99,7 @@ enum IDs {
 } ;
 
 
-KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
+KPicoSim::KPicoSim() : TDEMainWindow( 0, "KPicoSim" )
 {
 //	set the shell's ui resource file
 //	setXMLFile("kpicosimui.rc");
@@ -107,14 +107,14 @@ KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
 	m_splitter = new TQSplitter( this ) ;
 	m_tabWidget = new TQTabWidget( m_splitter ) ;
 	m_editor = new CodeEditor( m_tabWidget ) ;
-	m_messages = new KListView( m_splitter, "messages" ) ;
-	m_simulator = new KSimulator( TQT_TQOBJECT(this) ) ;
-	m_processorView = new KProcessorView( this ) ;
+	m_messages = new TDEListView( m_splitter, "messages" ) ;
+	m_simulator = new KSimulator( this ) ;
+	m_processorView = new TDEProcessorView( this ) ;
 
 	m_tabWidget->addTab( m_editor, "Source" ) ;
 	addDockWindow( m_processorView, DockLeft ) ;
 
-	m_splitter->setOrientation( Qt::Vertical ) ;
+	m_splitter->setOrientation( TQt::Vertical ) ;
 	setCentralWidget( m_splitter ) ;
 	m_messages->setAllColumnsShowFocus( true ) ;
 	m_messages->setFullWidth( true ) ;
@@ -122,31 +122,31 @@ KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
 
 	buildMenu() ;
 
-	KToolBar *toolbar = new KToolBar( this ) ;
+	TDEToolBar *toolbar = new TDEToolBar( this ) ;
 	addDockWindow( toolbar ) ;
 
-	toolbar->insertButton( "filenew", -1, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(m_editor), TQT_SLOT( slotNewFile() ), true, "New" ) ;
-	toolbar->insertButton( "fileopen", -1, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(m_editor), TQT_SLOT( slotOpen() ), true, "Open" ) ;
-	toolbar->insertButton( "filesave", -1, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(m_editor), TQT_SLOT( slotSave() ), true, "Save" ) ;
-	toolbar->insertButton( "filesaveas", -1, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(m_editor), TQT_SLOT( slotSaveAs() ), true, "Save As" ) ;
+	toolbar->insertButton( "document-new", -1, TQ_SIGNAL( clicked() ), m_editor, TQ_SLOT( slotNewFile() ), true, "New" ) ;
+	toolbar->insertButton( "document-open", -1, TQ_SIGNAL( clicked() ), m_editor, TQ_SLOT( slotOpen() ), true, "Open" ) ;
+	toolbar->insertButton( "document-save", -1, TQ_SIGNAL( clicked() ), m_editor, TQ_SLOT( slotSave() ), true, "Save" ) ;
+	toolbar->insertButton( "document-save-as", -1, TQ_SIGNAL( clicked() ), m_editor, TQ_SLOT( slotSaveAs() ), true, "Save As" ) ;
 
-	m_debugBar = new KToolBar( this ) ;
+	m_debugBar = new TDEToolBar( this ) ;
 	addDockWindow( m_debugBar ) ;
-	m_debugBar->insertButton( UserIcon( "rebuild" ), COMPILE_ID, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), TQT_SLOT( compile() ), true, "Compile" ) ;
-	m_debugBar->insertButton( "run", START_SIM_ID, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), TQT_SLOT( startSim() ), true, "Start/Stop Debug" ) ;
+	m_debugBar->insertButton( UserIcon( "rebuild" ), COMPILE_ID, TQ_SIGNAL( clicked() ), this, TQ_SLOT( compile() ), true, "Compile" ) ;
+	m_debugBar->insertButton( "system-run", START_SIM_ID, TQ_SIGNAL( clicked() ), this, TQ_SLOT( startSim() ), true, "Start/Stop Debug" ) ;
 	m_debugBar->insertSeparator() ;
-	m_debugBar->insertButton( UserIcon( "continue" ), RUN_ID, TQT_SIGNAL( clicked() ), TQT_TQOBJECT(this), TQT_SLOT( startStop() ), false, "Continue" ) ;
+	m_debugBar->insertButton( UserIcon( "continue" ), RUN_ID, TQ_SIGNAL( clicked() ), this, TQ_SLOT( startStop() ), false, "Continue" ) ;
 
-	m_debugBar->insertButton( UserIcon( "next" ), NEXT_ID, TQT_SIGNAL( clicked() ), m_simulator, TQT_SLOT( next() ), false, "Next" ) ;
-	m_debugBar->insertButton( UserIcon( "interrupt" ), INTERRUPT_ID, TQT_SIGNAL( clicked() ), m_simulator, TQT_SLOT( interrupt() ), false, "Interrupt" ) ; 
-	m_debugBar->insertButton( UserIcon( "reset" ), RESET_ID, TQT_SIGNAL( clicked() ), m_simulator, TQT_SLOT( reset() ), false, "Reset" ) ;
+	m_debugBar->insertButton( UserIcon( "next" ), NEXT_ID, TQ_SIGNAL( clicked() ), m_simulator, TQ_SLOT( next() ), false, "Next" ) ;
+	m_debugBar->insertButton( UserIcon( "interrupt" ), INTERRUPT_ID, TQ_SIGNAL( clicked() ), m_simulator, TQ_SLOT( interrupt() ), false, "Interrupt" ) ; 
+	m_debugBar->insertButton( UserIcon( "reset" ), RESET_ID, TQ_SIGNAL( clicked() ), m_simulator, TQ_SLOT( reset() ), false, "Reset" ) ;
 
-	connect( TQT_TQOBJECT(this), TQT_SIGNAL( run() ), m_simulator, TQT_SLOT( run() ) );
-	connect( TQT_TQOBJECT(this), TQT_SIGNAL( stop()  ), m_simulator, TQT_SLOT( stop()  ) ) ;
-	connect( m_simulator, TQT_SIGNAL( stepped( unsigned int ) ), TQT_TQOBJECT(this), TQT_SLOT( stepped( unsigned int ) ) ) ;
-	connect( m_processorView, TQT_SIGNAL( processorRegsChanged() ), TQT_TQOBJECT(this), TQT_SLOT( updateProcessorRegs() ) ) ;
-	connect( m_processorView, TQT_SIGNAL( processorFlagsChanged() ), TQT_TQOBJECT(this), TQT_SLOT( updateProcessorFlags() ) ) ;
-	connect( m_messages, TQT_SIGNAL( clicked( TQListViewItem * ) ), TQT_TQOBJECT(this), TQT_SLOT( messageListClicked( TQListViewItem * ) ) ) ;
+	connect( this, TQ_SIGNAL( run() ), m_simulator, TQ_SLOT( run() ) );
+	connect( this, TQ_SIGNAL( stop()  ), m_simulator, TQ_SLOT( stop()  ) ) ;
+	connect( m_simulator, TQ_SIGNAL( stepped( unsigned int ) ), this, TQ_SLOT( stepped( unsigned int ) ) ) ;
+	connect( m_processorView, TQ_SIGNAL( processorRegsChanged() ), this, TQ_SLOT( updateProcessorRegs() ) ) ;
+	connect( m_processorView, TQ_SIGNAL( processorFlagsChanged() ), this, TQ_SLOT( updateProcessorFlags() ) ) ;
+	connect( m_messages, TQ_SIGNAL( clicked( TQListViewItem * ) ), this, TQ_SLOT( messageListClicked( TQListViewItem * ) ) ) ;
 
 	m_messages->addColumn( "Line" ) ;
 	m_messages->addColumn( "Description" ) ;
@@ -172,73 +172,73 @@ KPicoSim::KPicoSim() : KMainWindow( 0, "KPicoSim" )
 
 void KPicoSim::buildMenu()
 {
-	KIconLoader * ldr = KGlobal::iconLoader() ;
+	TDEIconLoader * ldr = TDEGlobal::iconLoader() ;
 
-	KPopupMenu * exportMenu = new KPopupMenu( this ) ;
+	TDEPopupMenu * exportMenu = new TDEPopupMenu( this ) ;
 
-	exportMenu->insertItem( "VHDL", TQT_TQOBJECT(this), TQT_SLOT( fileExportVHDL() ) ) ;
-//	exportMenu->insertItem( "COE", TQT_TQOBJECT(this), TQT_SLOT( fileExportCOE() ) ) ;
-	exportMenu->insertItem( "MEM", TQT_TQOBJECT(this), TQT_SLOT( fileExportMEM() ) ) ;
-	exportMenu->insertItem( "HEX", TQT_TQOBJECT(this), TQT_SLOT( fileExportHEX() ) ) ;
+	exportMenu->insertItem( "VHDL", this, TQ_SLOT( fileExportVHDL() ) ) ;
+//	exportMenu->insertItem( "COE", this, TQ_SLOT( fileExportCOE() ) ) ;
+	exportMenu->insertItem( "MEM", this, TQ_SLOT( fileExportMEM() ) ) ;
+	exportMenu->insertItem( "HEX", this, TQ_SLOT( fileExportHEX() ) ) ;
 
-	m_fileMenu = new KPopupMenu( this ) ;
-	m_fileMenu->insertItem( ldr->loadIcon( "filenew", KIcon::Small ), "New", TQT_TQOBJECT(this), TQT_SLOT( slotFileNew() ) ) ;
-	m_fileMenu->insertItem( ldr->loadIcon( "fileopen", KIcon::Small ), "Open", TQT_TQOBJECT(m_editor), TQT_SLOT( slotOpen() ) ) ;
+	m_fileMenu = new TDEPopupMenu( this ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "document-new", TDEIcon::Small ), "New", this, TQ_SLOT( slotFileNew() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "document-open", TDEIcon::Small ), "Open", m_editor, TQ_SLOT( slotOpen() ) ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( ldr->loadIcon( "filesave", KIcon::Small ), "Save", TQT_TQOBJECT(m_editor), TQT_SLOT( slotSave() ), TQKeySequence( "CTRL+S" ) ) ;
-	m_fileMenu->insertItem( ldr->loadIcon( "filesaveas", KIcon::Small ), "Save As...", TQT_TQOBJECT(m_editor), TQT_SLOT( slotSaveAs() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "document-save", TDEIcon::Small ), "Save", m_editor, TQ_SLOT( slotSave() ), TQKeySequence( "CTRL+S" ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "document-save-as", TDEIcon::Small ), "Save As...", m_editor, TQ_SLOT( slotSaveAs() ) ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( ldr->loadIcon( "fileprint", KIcon::Small ), "Print...", TQT_TQOBJECT(m_editor), TQT_SLOT( slotPrint() ), TQKeySequence( "CTRL+P" ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "document-print", TDEIcon::Small ), "Print...", m_editor, TQ_SLOT( slotPrint() ), TQKeySequence( "CTRL+P" ) ) ;
 	m_fileMenu->insertSeparator() ;
 	m_fileMenu->insertItem( "Export", exportMenu ) ;
 	m_fileMenu->insertSeparator() ;
-	m_fileMenu->insertItem( ldr->loadIcon( "fileclose", KIcon::Small ), "Quit", TQT_TQOBJECT(this), TQT_SLOT( slotClose() ) ) ;
+	m_fileMenu->insertItem( ldr->loadIcon( "window-close", TDEIcon::Small ), "Quit", this, TQ_SLOT( slotClose() ) ) ;
 
-	m_editMenu = new KPopupMenu( this ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "undo", KIcon::Small ), "Undo", TQT_TQOBJECT(m_editor), TQT_SLOT( slotUndo() ),TQKeySequence( "CTRL+Z" ) ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "redo", KIcon::Small ), "Redo", TQT_TQOBJECT(m_editor), TQT_SLOT( slotRedo() ),TQKeySequence( "CTRL+SHIFT+Z" ) ) ;
+	m_editMenu = new TDEPopupMenu( this ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "edit-undo", TDEIcon::Small ), "Undo", m_editor, TQ_SLOT( slotUndo() ),TQKeySequence( "CTRL+Z" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "edit-redo", TDEIcon::Small ), "Redo", m_editor, TQ_SLOT( slotRedo() ),TQKeySequence( "CTRL+SHIFT+Z" ) ) ;
 	m_editMenu->insertSeparator() ;
-	m_editMenu->insertItem( "Select All", TQT_TQOBJECT(m_editor), TQT_SLOT( slotSelectAll() ),TQKeySequence( "CTRL+A" ) ) ;
+	m_editMenu->insertItem( "Select All", m_editor, TQ_SLOT( slotSelectAll() ),TQKeySequence( "CTRL+A" ) ) ;
 	m_editMenu->insertSeparator() ;
-	m_editMenu->insertItem( ldr->loadIcon( "editcut", KIcon::Small ), "Cut", TQT_TQOBJECT(m_editor), TQT_SLOT( slotCut() ),TQKeySequence( "CTRL+X" ) ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "editcopy", KIcon::Small ), "Copy", TQT_TQOBJECT(m_editor), TQT_SLOT( slotCopy() ),TQKeySequence( "CTRL+C" ) ) ;
-	m_editMenu->insertItem( ldr->loadIcon( "editpaste", KIcon::Small ), "Paste", TQT_TQOBJECT(m_editor), TQT_SLOT( slotPaste() ),TQKeySequence( "CTRL+V" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "edit-cut", TDEIcon::Small ), "Cut", m_editor, TQ_SLOT( slotCut() ),TQKeySequence( "CTRL+X" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "edit-copy", TDEIcon::Small ), "Copy", m_editor, TQ_SLOT( slotCopy() ),TQKeySequence( "CTRL+C" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "edit-paste", TDEIcon::Small ), "Paste", m_editor, TQ_SLOT( slotPaste() ),TQKeySequence( "CTRL+V" ) ) ;
 	m_editMenu->insertSeparator() ;
-	m_editMenu->insertItem( ldr->loadIcon( "find", KIcon::Small ), "Find...", TQT_TQOBJECT(m_editor), TQT_SLOT( slotFind() ), TQKeySequence( "CTRL+F" ) ) ;
-	m_editMenu->insertItem( "Find Next", TQT_TQOBJECT(m_editor), TQT_SLOT( slotFindNext() ), TQKeySequence( "F3" ) ) ;
+	m_editMenu->insertItem( ldr->loadIcon( "edit-find", TDEIcon::Small ), "Find...", m_editor, TQ_SLOT( slotFind() ), TQKeySequence( "CTRL+F" ) ) ;
+	m_editMenu->insertItem( "Find Next", m_editor, TQ_SLOT( slotFindNext() ), TQKeySequence( "F3" ) ) ;
 
 
-	m_debugMenu = new KPopupMenu( this ) ;
+	m_debugMenu = new TDEPopupMenu( this ) ;
 	m_debugMenu->insertSeparator() ;
-	m_debugMenu->insertItem( ldr->loadIcon( "rebuild", KIcon::Small ), "Compile", TQT_TQOBJECT(this), TQT_SLOT( compile() ), TQKeySequence( "SHIFT+F9" ) ) ;
-	m_debugMenu->insertItem( ldr->loadIcon( "run", KIcon::Small ), "Start Debug", TQT_TQOBJECT(this), TQT_SLOT( startSim() ), TQKeySequence( "F9" ) , START_SIM_ID ) ;
+	m_debugMenu->insertItem( ldr->loadIcon( "rebuild", TDEIcon::Small ), "Compile", this, TQ_SLOT( compile() ), TQKeySequence( "SHIFT+F9" ) ) ;
+	m_debugMenu->insertItem( ldr->loadIcon( "system-run", TDEIcon::Small ), "Start Debug", this, TQ_SLOT( startSim() ), TQKeySequence( "F9" ) , START_SIM_ID ) ;
 
 	m_debugMenu->insertSeparator() ;
-	m_debugMenu->insertItem( "Continue", TQT_TQOBJECT(this), TQT_SLOT( startStop() ), TQKeySequence( "F10" ) , RUN_ID ) ;
-	m_debugMenu->insertItem( "Next", m_simulator, TQT_SLOT( next() ), TQKeySequence( "F5" ) , NEXT_ID ) ;
-	m_debugMenu->insertItem( "Interrupt", m_simulator, TQT_SLOT( interrupt() ), TQKeySequence( "F4" ) , INTERRUPT_ID ) ;
-	m_debugMenu->insertItem( "Reset", m_simulator, TQT_SLOT( reset() ), TQKeySequence( "F11" ) , RESET_ID ) ;
+	m_debugMenu->insertItem( "Continue", this, TQ_SLOT( startStop() ), TQKeySequence( "F10" ) , RUN_ID ) ;
+	m_debugMenu->insertItem( "Next", m_simulator, TQ_SLOT( next() ), TQKeySequence( "F5" ) , NEXT_ID ) ;
+	m_debugMenu->insertItem( "Interrupt", m_simulator, TQ_SLOT( interrupt() ), TQKeySequence( "F4" ) , INTERRUPT_ID ) ;
+	m_debugMenu->insertItem( "Reset", m_simulator, TQ_SLOT( reset() ), TQKeySequence( "F11" ) , RESET_ID ) ;
 
 	m_debugMenu->insertSeparator() ;
-	m_debugMenu->insertItem( "Toggle Breakpoint", TQT_TQOBJECT(m_editor), TQT_SLOT( slotToggleBreakpoint() ), TQKeySequence( "F8" ) ) ;
+	m_debugMenu->insertItem( "Toggle Breakpoint", m_editor, TQ_SLOT( slotToggleBreakpoint() ), TQKeySequence( "F8" ) ) ;
 
-	m_settingsMenu = new KPopupMenu( this ) ;
-	m_settingsMenu->insertItem( "Configure Editor...", TQT_TQOBJECT(m_editor), TQT_SLOT( slotShowConfig() ) ) ;
+	m_settingsMenu = new TDEPopupMenu( this ) ;
+	m_settingsMenu->insertItem( "Configure Editor...", m_editor, TQ_SLOT( slotShowConfig() ) ) ;
 
-	m_peripheralMenu = new KPopupMenu( this ) ;
-	m_peripheralMenu->insertItem( "I/O Port", TQT_TQOBJECT(this), TQT_SLOT( newIOPort() ) ) ;
-	m_peripheralMenu->insertItem( "Scratchpad", TQT_TQOBJECT(this), TQT_SLOT( showScratchpad() ), 0, VIEW_SCRATCHPAD_ID ) ;
-	m_peripheralMenu->insertItem( "Serial port", TQT_TQOBJECT(this), TQT_SLOT( showSerialPort() ), 0, VIEW_SERIAL_ID ) ;
+	m_peripheralMenu = new TDEPopupMenu( this ) ;
+	m_peripheralMenu->insertItem( "I/O Port", this, TQ_SLOT( newIOPort() ) ) ;
+	m_peripheralMenu->insertItem( "Scratchpad", this, TQ_SLOT( showScratchpad() ), 0, VIEW_SCRATCHPAD_ID ) ;
+	m_peripheralMenu->insertItem( "Serial port", this, TQ_SLOT( showSerialPort() ), 0, VIEW_SERIAL_ID ) ;
 
-	m_jtagMenu = new KPopupMenu( this ) ;
-	m_jtagMenu->insertItem( "Download", TQT_TQOBJECT(this), TQT_SLOT( jtagDownload() ) ) ;
+	m_jtagMenu = new TDEPopupMenu( this ) ;
+	m_jtagMenu->insertItem( "Download", this, TQ_SLOT( jtagDownload() ) ) ;
 
-	KAboutData *aboutData = new KAboutData( 
+	TDEAboutData *aboutData = new TDEAboutData( 
 		"kpicosim", 
 		"kpicosim", 
 		version, 
 		"IDE for the picoblaze\n\nCopyright (c) 2005 Mark Six", 
-		KAboutData::License_GPL,
+		TDEAboutData::License_GPL,
 		0,
 		0,
 		"http://www.xs4all.nl/~marksix",
@@ -247,7 +247,7 @@ void KPicoSim::buildMenu()
 	aboutData->addAuthor( "Mark Six", "m6@xs4all.nl", "http://www.xs4all.nl/~marksix" ) ;
 
 	KHelpMenu *helpMenu = new KHelpMenu( this, aboutData, false  ) ;
-	KPopupMenu *help = helpMenu->menu() ;
+	TDEPopupMenu *help = helpMenu->menu() ;
 
 	menuBar()->insertItem( "File", m_fileMenu ) ;
 	menuBar()->insertItem( "Edit", m_editMenu ) ;
@@ -367,7 +367,7 @@ void KPicoSim::newIOPort()
 	KPortView * ioport = new KPortView( m_simulator->getCpu(), 0 ) ;			/* port id is 0 */
 //	m_ioList.append( ioport ) ;
 	addDockWindow( ioport, DockRight ) ;
-//	connect( ioport, TQT_SIGNAL( closing( KPortView* ) ), TQT_TQOBJECT(this), TQT_SLOT( removeIOPort( KPortView* ) ) ) ;
+//	connect( ioport, TQ_SIGNAL( closing( KPortView* ) ), this, TQ_SLOT( removeIOPort( KPortView* ) ) ) ;
 }
 
 void KPicoSim::showSerialPort()
@@ -533,12 +533,12 @@ bool KPicoSim::compile()
 
 void KPicoSim::startSim()
 {
-	KIconLoader * ldr = KGlobal::iconLoader() ;
+	TDEIconLoader * ldr = TDEGlobal::iconLoader() ;
 
 	if ( !m_simulationMode ) {
 		if ( compile() ) {
 			setCaption( m_editor->getFilename() + " [Debugging]" ) ;
-			m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "stop", KIcon::Small ), "Stop Debug" ) ;
+			m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "process-stop", TDEIcon::Small ), "Stop Debug" ) ;
 			m_debugBar->setButton( START_SIM_ID, true ) ;
 
 			m_simulator->reset() ;
@@ -548,20 +548,20 @@ void KPicoSim::startSim()
 	} else {
 		if ( m_simulator->isRunning() )
 			startStop() ;
-			
+
 		setCaption( m_editor->getFilename() ) ;
-		m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "run", KIcon::Small ), "Start Debug" ) ;
+		m_debugMenu->changeItem( START_SIM_ID, ldr->loadIcon( "system-run", TDEIcon::Small ), "Start Debug" ) ;
 		m_debugBar->setButton( START_SIM_ID, false ) ;
 		m_editor->clearExecutionMarker() ;
 		m_simulationMode = FALSE ;
 	}
-	
+
 	if ( m_simulationMode ) {
 		statusBar()->changeItem( TQString( "Mode: Debug" ), 0 ) ;
 	} else {
 		statusBar()->changeItem( TQString( "Mode: Edit" ), 0 ) ;
 	}
-	
+
 	m_debugMenu->setItemEnabled( RUN_ID, m_simulationMode ) ;
 	m_debugMenu->setItemEnabled( NEXT_ID, m_simulationMode ) ;
 	m_debugMenu->setItemEnabled( INTERRUPT_ID, m_simulationMode ) ;
@@ -623,7 +623,7 @@ void KPicoSim::openGUI()
 		ioport->readConfig( config, group ) ;
 		m_ioList.append( ioport ) ;
 		addDockWindow( ioport, DockRight ) ;
-		connect( ioport, TQT_SIGNAL( closing( KPortView* ) ), TQT_TQOBJECT(this), TQT_SLOT( removeIOPort( KPortView* ) ) ) ;
+		connect( ioport, TQ_SIGNAL( closing( KPortView* ) ), this, TQ_SLOT( removeIOPort( KPortView* ) ) ) ;
 	}
 */
 }
