@@ -31,7 +31,7 @@ KSimulator::KSimulator(TQObject *parent, const char *name )
 	
 	m_timer->stop() ;
 	m_run = false ;
-	connect( m_timer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( next() ) ) ;
+	connect( m_timer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( next() ) ) ;
 }
 
 KSimulator::~KSimulator()
